@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: smart-bookmarks-extension.c,v 1.16 2005/09/09 15:58:35 jframeau Exp $
+ *  $Id: smart-bookmarks-extension.c,v 1.17.2.1 2006/03/23 23:11:36 jframeau Exp $
  */
 
 #include "config.h"
@@ -134,15 +134,15 @@ search_gnome_dict_cb (GtkAction *action,
 		      EphyWindow *window)
 {
 	EphyEmbed *embed;
-	char *argv[3] = { "gnome-dictionary", NULL, NULL };
+	char *argv[4] = { "gnome-dictionary", "--look-up", NULL, NULL };
 	GError *error = NULL;
 
 	embed = ephy_window_get_active_embed (window);
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
 	/* ask Mozilla the selection */
-	argv[1] = mozilla_get_selected_text (embed);
-	if (argv[1] == NULL) return;
+	argv[2] = mozilla_get_selected_text (embed);
+	if (argv[2] == NULL) return;
 
 	g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, &error);
 
@@ -152,7 +152,7 @@ search_gnome_dict_cb (GtkAction *action,
 		g_error_free (error);
 	}
 
-	g_free (argv[1]);
+	g_free (argv[2]);
 }
 
 static void 
@@ -311,20 +311,6 @@ rebuild_ui (WindowData *data)
 			       LOOKUP_ACTION "Menu", LOOKUP_ACTION,
 			       GTK_UI_MANAGER_MENU, FALSE);
 
-	/* Add bookmarks to popup context (framed document) */
-	gtk_ui_manager_add_ui (manager, ui_id, "/EphyFramedDocumentPopup",
-			       "SmbExtSep0", NULL,
-			       GTK_UI_MANAGER_SEPARATOR, FALSE);
-	gtk_ui_manager_add_ui (manager, ui_id, "/EphyFramedDocumentPopup",
-			       LOOKUP_ACTION "Menu", LOOKUP_ACTION,
-			       GTK_UI_MANAGER_MENU, FALSE);
-	gtk_ui_manager_add_ui (manager, ui_id, "/EphyFullscreenFramedDocumentPopup",
-			       "SmbExtSep0", NULL,
-			       GTK_UI_MANAGER_SEPARATOR, FALSE);
-	gtk_ui_manager_add_ui (manager, ui_id, "/EphyFullscreenFramedDocumentPopup",
-			       LOOKUP_ACTION "Menu", LOOKUP_ACTION,
-			       GTK_UI_MANAGER_MENU, FALSE);
-
 	/* Add bookmarks to input popup context */
 	gtk_ui_manager_add_ui (manager, ui_id, "/EphyInputPopup",
 			       "SmbExtSep0", NULL,
@@ -355,18 +341,10 @@ rebuild_ui (WindowData *data)
 				       "/EphyDocumentPopup/" LOOKUP_ACTION "Menu",
 				       verb, verb,
 				       GTK_UI_MANAGER_MENUITEM, FALSE);
-		gtk_ui_manager_add_ui (manager, ui_id,
-				       "/EphyFramedDocumentPopup/" LOOKUP_ACTION "Menu",
-				       verb, verb,
-				       GTK_UI_MANAGER_MENUITEM, FALSE);
 		gtk_ui_manager_add_ui (manager, ui_id,
 				       "/EphyFullscreenDocumentPopup/" LOOKUP_ACTION "Menu",
 				       verb, verb,
 				       GTK_UI_MANAGER_MENUITEM, FALSE);
-		gtk_ui_manager_add_ui (manager, ui_id,
-				       "/EphyFullscreenFramedDocumentPopup/" LOOKUP_ACTION "Menu",
-				       verb, verb,
-				       GTK_UI_MANAGER_MENUITEM, FALSE);
 		gtk_ui_manager_add_ui (manager, ui_id,
 				       "/EphyInputPopup/" LOOKUP_ACTION "Menu",
 				       verb, verb,
@@ -384,14 +362,6 @@ rebuild_ui (WindowData *data)
 			       "/EphyFullscreenDocumentPopup/" LOOKUP_ACTION "Menu",
 			       GDICT_ACTION "FSIDP", GDICT_ACTION,
 			       GTK_UI_MANAGER_MENUITEM, FALSE);
-	gtk_ui_manager_add_ui (manager, ui_id,
-			       "/EphyFramedDocumentPopup/" LOOKUP_ACTION "Menu",
-			       GDICT_ACTION "IFDP", GDICT_ACTION,
-			       GTK_UI_MANAGER_MENUITEM, FALSE);
-	gtk_ui_manager_add_ui (manager, ui_id,
-			       "/EphyFullscreenFramedDocumentPopup/" LOOKUP_ACTION "Menu",
-			       GDICT_ACTION "FSIFDP", GDICT_ACTION,
-			       GTK_UI_MANAGER_MENUITEM, FALSE);
 	gtk_ui_manager_add_ui (manager, ui_id,
 			       "/EphyInputPopup/" LOOKUP_ACTION "Menu",
 			       GDICT_ACTION "INPUTP", GDICT_ACTION,
