@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gui.h,v 1.6 2005/09/21 19:49:13 chpe Exp $
+ *  $Id: ephy-gui.h,v 1.7.2.1 2006/04/09 20:24:25 chpe Exp $
  */
 
 #ifndef EPHY_GUI_H
@@ -61,6 +61,10 @@ void		ephy_gui_menu_position_on_panel		 (GtkMenu *menu,
 
 GtkWindowGroup *ephy_gui_ensure_window_group		 (GtkWindow *window);
 
+void		ephy_gui_get_current_event		 (GdkEventType *type,
+							  guint *state,
+							  guint *button);
+
 gboolean	ephy_gui_is_middle_click		 (void);
 
 gboolean	ephy_gui_check_location_writable         (GtkWidget *parent,
@@ -70,11 +74,15 @@ void		ephy_gui_help				 (GtkWindow *parent,
 							  const char *file_name,
 							  const char *link_id);
 
+void		ephy_gui_help_with_doc_id		 (GtkWindow *parent,
+							  const char *doc_id,
+							  const char *file_name,
+							  const char *link_id);
+
 void		ephy_gui_window_update_user_time	 (GtkWidget *window,
 							  guint32 user_time);
 
-void		ephy_gui_window_present			 (GtkWindow *window,
-							  guint32 user_time);
+GtkWidget      *ephy_gui_message_dialog_get_content_box	 (GtkWidget *dialog);
 
 G_END_DECLS
 
